@@ -1,5 +1,11 @@
 # -*- coding: utf-8 -*-
 
+###########################################################################
+## File:		functions_record.py
+## Description: This file includes the functions needed to modify and read
+##				the data in the file record.py
+###########################################################################
+
 import sys
 import os
 import random
@@ -19,7 +25,7 @@ import records #record data
 #own functions
 from functions_general import *
 
-#own c cfunctions (for speed improvements)
+#own c functions (for speed improvements)
 try:
     from lib import mylib
 except:
@@ -27,7 +33,12 @@ except:
 
 
 ###########################################################################
-## Read the sensor data x times and smoothen it
+## Function:    ReadAccSensor
+## Description: Reads the acceleration sensor for x times, where
+##				x=data.Sample_smoothing (normally 10) and averages it
+##				If not on a N900, use randomizer as input
+## Parameters:  none
+## Returns:     array of accelerations
 ###########################################################################
 def ReadAccSensor():
     coords=[0, 0, 0]
@@ -50,37 +61,51 @@ def ReadAccSensor():
 
 
 
+
+
+###########################################################################
+## Function:    GetSensorData
+## Description: This function initiates the sensor readings.
+##				It gets called once every second from MeasurementTimerLoop()
+##				The from ReadAccSensor returned data gets written into a
+##				temporary buffer. After x times
+##				(where x=data.Value_smoothing, usually 10) it gets averaged
+##				again and finally filled into the records array
+## Parameters:  none
+## Returns:     1 if new data got added to record array, else 0
+###########################################################################
+
 ###########################################################################
 ## Get the smoothened sensor data, smoothen it again and fill the data into the main data array
 ###########################################################################
 def GetSensorData():
     d=ReadAccSensor()
-    data.arrDataTemp[0]=data.arrDataTemp[0]+d[0]
-    data.arrDataTemp[1]=data.arrDataTemp[1]+d[1]
-    data.arrDataTemp[2]=data.arrDataTemp[2]+d[2]
+    data.arrDataTemp[0]=data.arrDataTemp[0]+d[0] #X
+    data.arrDataTemp[1]=data.arrDataTemp[1]+d[1] #Y
+    data.arrDataTemp[2]=data.arrDataTemp[2]+d[2] #Z
 
     data.sample_index=data.sample_index+1
 
     if(data.sample_index==data.Value_smoothing): #if is 10 runs over
         data.sample_index=0
-        data.Values_total=data.Values_total+1
+#        data.Values_total=data.Values_total+1
 
         if(records.Index==records.MaxArrayDataLen-1): return 0 #Array full
 
         records.arrData[0][records.Index]=strftime("%H:%M:%S", time.localtime())
-        records.arrData[1][records.Index]=data.arrDataTemp[0]/data.Value_smoothing #note: indices are shifted in arrData!
-        records.arrData[2][records.Index]=data.arrDataTemp[1]/data.Value_smoothing
-        records.arrData[3][records.Index]=data.arrDataTemp[2]/data.Value_smoothing
+        records.arrData[1][records.Index]=data.arrDataTemp[0]/data.Value_smoothing #X #note: indices are shifted in arrData!
+        records.arrData[2][records.Index]=data.arrDataTemp[1]/data.Value_smoothing #Y
+        records.arrData[3][records.Index]=data.arrDataTemp[2]/data.Value_smoothing #Z
 
         records.Index=records.Index+1
-        records.LastIndex=max(records.Index,  records.LastIndex)
+        records.LastIndex=max(records.Index, records.LastIndex)
 
         records.EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
         records.EndTime_tuple=Seconds2Tuple(records.EndTime_seconds)
 
-        data.arrDataTemp[0]=0
-        data.arrDataTemp[1]=0
-        data.arrDataTemp[2]=0
+        data.arrDataTemp[0]=0 #X
+        data.arrDataTemp[1]=0 #Y
+        data.arrDataTemp[2]=0 #Z
 
         return 1 #added new values to arrData
     else: return 0 #no new data added
@@ -89,7 +114,11 @@ def GetSensorData():
 
 
 ###########################################################################
-##
+## Function:    GetFirstEntry
+## Description: This function fills in the start time and dummy
+##				acceleration data, so the record array is not empty
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def GetFirstEntry():
     records.arrData[0][0]=strftime("%H:%M:%S", time.localtime())
@@ -98,24 +127,32 @@ def GetFirstEntry():
     records.arrData[3][0]=0 #Z
 
     records.Index=1
-    records.LastIndex=max(records.Index,  records.LastIndex)
+    records.LastIndex=max(records.Index, records.LastIndex)
+
 
 
 
 
 ###########################################################################
-##  Process the data, generate movement indication
+## Function:    GenerateDerivation
+## Description: This function processes the recorded data in the record array
+##				The acceleration sensor data (which contains the data of the
+##				relative position of the phone) gets derivated into its derivat.
+##				This shows spices every time the phone changes the relative position
+##				The yellow bars in the graph exactly show this data.
+##				If parameter ProcessAll is False, only the last added data
+##				gets processed. This saves CPU time
+## Parameters:  ProcessAll: True/False
+## Returns:     none
 ###########################################################################
-def ProcessData(ProcessAll=False, ShowSleepPattern=False):  #DERIVATION (ABLEITUNG)
-    if(data.debug==True): print "Process Data (Process whole array:", ProcessAll,  ")"
+def GenerateDerivation(ProcessAll=False):  #DERIVATION (ABLEITUNG)
+    if(data.debug==True): print "Process Data (Process whole array:", ProcessAll, ")"
     data.Progress="Process data..."
     lastmovebeforegraph=0
     if(ProcessAll==True): start=0 #process whole array
     else: start=records.Index-data.Derivation-1 #process only last (changed) records
     if(data.debug==True): print "Process entry", start+data.Derivation, "to", records.Index
 
-
-
     for i in range(start, records.Index-data.Derivation):
         t=i*(records.Sampling_interval*records.Value_smoothing)/1000
         if(data.QuickMode==True or t>data.DelayStartTime):
@@ -130,47 +167,61 @@ def ProcessData(ProcessAll=False, ShowSleepPattern=False):  #DERIVATION (ABLEITU
             XYZderivation=0
         records.arrData[4][i]=abs(XYZderivation-data.derivation_offset)
 
-#    for i in range(0, min(records.Index-data.Derivation, 200)): records.arrData[4][i]=20 #debug
-
     #noise reduction of derivation
-    for i in range(data.noiseReduction,  records.Index-data.Derivation):
+#    for i in range(data.noiseReduction, records.Index-data.Derivation):
 #        val=0
 #        for j in range(0, data.noiseReduction):
 #            val+=records.arrData[4][i-j]
 #        records.arrData[5][i]  = val/data.noiseReduction
+#        records.arrData[5][i]  = records.arrData[4][i]
+
+    for i in range(start, records.Index-data.Derivation):
         records.arrData[5][i]  = records.arrData[4][i]
 
 
 
 
 
-
-
+###########################################################################
+## Function:    GenerateSleepPattern
+## Description: This function calculates the sleep pattern out of the movement
+##				data calculated in GenerateDerivation().
+##				It multiplies every derivation value with a defined array,
+##				which is defined in file filterdata.py
+##				As this process is very time consuming, it is exported into
+##				a c function. mylib.py contains the Python function, which
+##				gets converted into a c function by ShedSkin, a Python to C compiler.
+##				If the  c module mylib.so is missing, Python falls back to the
+##				slower Python function.
+## Parameters:  none
+## Returns:     none
+###########################################################################
+ #Recalculate sleep pattern curve (Note: This function is very time consuming)
 def GenerateSleepPattern():
     #NOTE:
-    #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
+    #records.arrData has strings and integers mixed. This ok in python, but does not work in C.
     #So we have to export the data and import it again afterwarts:
     arrSend=[0]*(records.Index+len(filter_data.arrFilter))
-    for i in range(0,  records.Index-data.Derivation): #copy array
+    for i in range(0, records.Index-data.Derivation): #copy array
         arrSend[i]=records.arrData[4][i]
 
     #Exported function:
     arrRet=mylib.CalculateSleepPattern(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.Yscale_Sleep_Pattern, data.Yoffset_Sleep_Pattern, data.Ysize-7, 13, data.limitMovement)
 
-    for i in range(0,  records.Index-data.Derivation): #copy array and scale
+    for i in range(0, records.Index-data.Derivation): #copy array and scale
         records.arrData[6][i]  = arrRet[i]
 
 
 
 
 
-
-
 ###########################################################################
-## Show the graph
-## the first parameter indicates on which window it will be drawn (record window or view window
+## Function:    DrawGraph
+## Description: This function draws the record array data into a bitmap
+## Parameters:  The target bitmap, QtGui
+## Returns:     none
 ###########################################################################
-def DrawGraph(self,  QtGui, ShowSleepPattern=False):
+def DrawGraph(self, QtGui):
     try:
         if(data.debug==True): print "Draw Graph into bitmap"
 
@@ -226,7 +277,7 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
         h=h0-2
         if(data.QuickMode==False): #normal mode
             if(data.Xscale==0): #max zoom
-                for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
+                for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade, decade): #full hours
                     h=(h+1) % 24
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10)
                     paint.setFont(QtGui.QFont('Decorative', 18))
@@ -242,7 +293,7 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
                         paint.drawLine(x2, data.Ysize, x2, data.Ysize+4)
 
             elif(data.Xscale==1 or data.Xscale==2): #mid + min zoom
-                for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
+                for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade, decade): #full hours
                     h=(h+1) % 24
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10)
                     paint.drawText(i-15, data.Ysize+30, str(h)+":00")
@@ -286,42 +337,39 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
 
         #movement bars (yellow bars)
         paint.setPen(QtGui.QColor(data.MovementBarColor))
-        for p in range(0,  records.Index-data.Derivation,  Xscale):
+        for p in range(0, records.Index-data.Derivation, Xscale):
             i=p-GraphStart_index
             peak=0
             for j in range(0, Xscale):
                 if(records.arrData[5][p+j]>peak): peak=records.arrData[5][p+j]
             x=i/Xscale
             if(peak==""): peak=0 #temporary bugfix
-            h=min(peak*data.Yscale_Movement/40,  data.Ysize-17) #cut off if higher than graph border
+            h=min(peak*data.Yscale_Movement/40, data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
-        #sleep graph (blue graph)
-        if(ShowSleepPattern==True):
-            pen=QtGui.QPen()
+    #sleep graph (blue graph)
+	pen=QtGui.QPen()
 
-            #sleep pattern filling
-            pen.setColor(QtGui.QColor(19, 54, 255, 150))
-            pen.setWidth(1)
-            paint.setPen(pen)
-            for p in range(0,  records.Index-data.Derivation-Xscale,  Xscale):
-                i=p-GraphStart_index
-                x=i/Xscale+1
-                y=data.Ysize-records.arrData[6][p+Xscale]-5
-                paint.drawLine(x, data.Ysize-16,       x, y)
+	pen.setColor(QtGui.QColor(19, 54, 255, 150))
+	pen.setWidth(1)
+	paint.setPen(pen)
+	for p in range(0, records.Index-data.Derivation-Xscale, Xscale): #sleep pattern filling
+		i=p-GraphStart_index
+		x=i/Xscale+1
+		y=data.Ysize-records.arrData[6][p+Xscale]-5
+		paint.drawLine(x, data.Ysize-16, x, y)
 
-            #sleep pattern outline
-            pen.setColor(QtGui.QColor(19, 54, 255))
-            pen.setWidth(3) #3
-            paint.setPen(pen)
-            for p in range(0,  records.Index-data.Derivation-Xscale,  Xscale):
-                i=p-GraphStart_index
-                x=i/Xscale+1
-                y0=data.Ysize-records.arrData[6][p]-5
-                y1=data.Ysize-records.arrData[6][p+Xscale]-5
-                paint.drawLine(x, y0,       x+1, y1)
+	pen.setColor(QtGui.QColor(19, 54, 255))
+	pen.setWidth(3) #3
+	paint.setPen(pen)
+	for p in range(0, records.Index-data.Derivation-Xscale, Xscale): #sleep pattern outline
+		i=p-GraphStart_index
+		x=i/Xscale+1
+		y0=data.Ysize-records.arrData[6][p]-5
+		y1=data.Ysize-records.arrData[6][p+Xscale]-5
+		paint.drawLine(x, y0, x+1, y1)
 
-       #Lucid dream option
+        #Lucid dream option
         if(records.Use_Lucid_Dream_Song==True and records.Lucid_Dream_Song_Start_tuple!=-1):
             paint.setBrush(QtGui.QColor(data.Lucid_Dream_Color))
             paint.setPen(QtGui.QColor(data.Lucid_Dream_Color))
@@ -335,7 +383,7 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
             x01=(x1-GraphStart_index)/Xscale
             y=20
             paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
-            paint.drawRect(x00,  y-1,  x01-x00,  2)
+            paint.drawRect(x00, y-1, x01-x00, 2)
 
        #WakeUp option
         if(records.Use_WakeUp_Song==True and records.WakeUp_Song_Start_tuple!=-1):
@@ -348,7 +396,7 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
             x01=(x1-GraphStart_index)/Xscale
             y=20
             paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
-            paint.drawRect(x00,  y-1,  x01-x00,  2)
+            paint.drawRect(x00, y-1, x01-x00, 2)
 
        #alarm visualisation
         if(records.AlarmIsSet==True): #alarm time window is set, show it
@@ -358,8 +406,8 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
             x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation*Xscale
             x00=(x0-GraphStart_index)/Xscale
             x10=(x1-GraphStart_index)/Xscale
-            paint.drawRect(x00,  8,  x10-x00,  2) #Time Window
-            paint.drawRect(x10,  4,  1,  10)  #Last Alarm opportunity
+            paint.drawRect(x00, 8, x10-x00, 2) #Time Window
+            paint.drawRect(x10, 4, 1, 10)  #Last Alarm opportunity
 
             if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in view mode
                 if(records.AlarmTime_seconds!=-1):
@@ -371,7 +419,7 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
                             a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
                         a00=(a0-GraphStart_index)/Xscale
 
-                        gradient = QtGui.QRadialGradient(a00,  20,  3)
+                        gradient = QtGui.QRadialGradient(a00, 20, 3)
                         gradient.setColorAt(0, QtGui.QColor(255, 152, 152))
                         gradient.setColorAt(1, QtGui.QColor(255, 0, 0))
                         paint.setBrush(QtGui.QBrush(gradient))
@@ -385,16 +433,16 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
                 else:
                     t=data.Trigger
                 y=(data.Ysize-(t*data.Yscale_Sleep_Pattern*3/40))+10
-                paint.setPen(QtGui.QColor(255,  255,  255, 200))
+                paint.setPen(QtGui.QColor(255, 255, 255, 200))
                 paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
                 if(y<18):
                     y=33
                     #draw arrow
                     xa=data.GraphBitMapLen-37
                     ya=y-21
-                    paint.drawLine(xa, ya,    xa, ya-9) #arrow
-                    paint.drawLine(xa, ya-9,    xa-3, ya-6) #arrow
-                    paint.drawLine(xa, ya-9,    xa+3, ya-6) #arrow
+                    paint.drawLine(xa, ya, xa, ya-9) #arrow
+                    paint.drawLine(xa, ya-9, xa-3, ya-6) #arrow
+                    paint.drawLine(xa, ya-9, xa+3, ya-6) #arrow
                 elif(y<33):
                     y=y+17
                 paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
@@ -423,15 +471,19 @@ def DrawGraph(self,  QtGui, ShowSleepPattern=False):
 
 
 
+
 ###########################################################################
-## Make noise if sleep pattern is over trigge rlevel (quick mode only)
+## Function:    MakeNoise_if_over_trigger
+## Description: This function plays a wav file when ever the movement is
+##				over the trigger level.
+##				It is only used in quick mode measurement
+## Parameters:  current movement
+## Returns:     none
 ###########################################################################
 #TODO: improve function!!!!
 def MakeNoise_if_over_trigger(peak):
     #beep in test mode
-#    if(peak>data.Trigger): #if last value is over peak
     if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40)): #Trigger Alarm
-#        if(data.QuickMode==True and (records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
         if((records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
             if(data.debug==True): print "Beep"
             data.last_beep=records.Index
@@ -445,16 +497,19 @@ def MakeNoise_if_over_trigger(peak):
 
 
 ###########################################################################
-## Draw statistic bars
+## Function:    DrawStatistic
+## Description: This function draws the statistics into a bitmap
+## Parameters:  The target bitmap, QtGui
+## Returns:     none
 ###########################################################################
-def DrawStatistic(self,  QtGui, QtCore):
+def DrawStatistic(self, QtGui, QtCore):
     paint = QtGui.QPainter()
     paint.begin(self)
 
     #clear whole pitmap (remove old data)
     paint.setPen(QtGui.QColor(data.GraphBackground))
     paint.setBrush(QtGui.QColor(data.GraphBackground))
-    paint.drawRect(0, 0, data.StatisticsBitMapLen,  data.StatisticsBitMapHeight)
+    paint.drawRect(0, 0, data.StatisticsBitMapLen, data.StatisticsBitMapHeight)
 
     paint.setPen(QtGui.QColor(data.GraphBackground))
 
@@ -489,69 +544,40 @@ def DrawStatistic(self,  QtGui, QtCore):
 
 
 
+
+
+
 ###########################################################################
-##Generate data for statistics
+## Function:    GenerateStatisticData
+## Description: This function generates the statistics from the record
+##				data and puts it into the statistics array
+##				As this function also is time consuming, it is exported
+##				into a c function. See GenerateSleepPattern() for mre details
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def GenerateStatisticData():
-#    for i in range(0, 4): #clear array
-#        for j in range(0,  3): records.arrStatData[j][i]=0
-
     #NOTE:
-    #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
+    #records.arrData has strings and integers mixed. This ok in python, but does not work in C.
     #So we have to export the data and import it again afterwarts:
     arrSend=[0]*(records.Index+len(filter_data.arrFilter))
-    for i in range(0,  records.Index-data.Derivation): #copy array
+    for i in range(0, records.Index-data.Derivation): #copy array
         arrSend[i]=records.arrData[6][i]
 
     records.arrStatData=mylib.CalculateStatistic(arrSend, records.Index-data.Derivation, records.EndTime_seconds-records.StartTime_seconds, records.Sampling_interval*records.Value_smoothing/1000, data.Light_Sleep_Level, data.Deep_Sleep_Level)
 
-#    p=0
-#    p0=0
-#    while(p<records.Index-data.Derivation):
-#        if(records.arrData[6][p]>data.Light_Sleep_Level): #awake
-#            p0=p
-#            while(records.arrData[6][p]>data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
-#            records.arrStatData[0][0]=records.arrStatData[0][0]+p-p0 #Accumulated time for Awake
-#            records.arrStatData[0][1]=records.arrStatData[0][1]+1 #Amount of times in Awake
-#            if(records.arrStatData[0][2]<p-p0): records.arrStatData[0][2]=p-p0 #Max time in Awake
-#
-#        elif(records.arrData[6][p]>data.Deep_Sleep_Level): #light sleep
-#            p0=p
-#            while(records.arrData[6][p]>data.Deep_Sleep_Level and records.arrData[6][p]<=data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
-#            records.arrStatData[1][0]=records.arrStatData[1][0]+p-p0 #Accumulated time for Light sleep
-#            records.arrStatData[1][1]=records.arrStatData[1][1]+1#Amount of times in Light sleep
-#            if(records.arrStatData[1][2]<p-p0): records.arrStatData[1][2]=p-p0 #Max time in Light sleep
-#
-#        else:
-#            p0=p
-#            while(records.arrData[6][p]<=data.Deep_Sleep_Level and p<records.Index-data.Derivation): p=p+1
-#            records.arrStatData[2][0]=records.arrStatData[2][0]+p-p0 #Accumulated time for Deep sleep
-#            records.arrStatData[2][1]=records.arrStatData[2][1]+1#Amount of times in Deep sleep
-#            if(records.arrStatData[2][2]<p-p0): records.arrStatData[2][2]=p-p0 #Max time in Deep sleep
-#
-#    #Accumulated time/phase
-#    records.arrStatData[0][0]=records.arrStatData[0][0]*records.Sampling_interval*records.Value_smoothing/1000
-#    records.arrStatData[1][0]=records.arrStatData[1][0]*records.Sampling_interval*records.Value_smoothing/1000
-#    records.arrStatData[2][0]=records.arrStatData[2][0]*records.Sampling_interval*records.Value_smoothing/1000
-#
-#    #Max time/phase
-#    records.arrStatData[0][2]=records.arrStatData[0][2]*records.Sampling_interval*records.Value_smoothing/1000
-#    records.arrStatData[1][2]=records.arrStatData[1][2]*records.Sampling_interval*records.Value_smoothing/1000
-#    records.arrStatData[2][2]=records.arrStatData[2][2]*records.Sampling_interval*records.Value_smoothing/1000
-#
-#    #time percent
-#    t_total=(records.EndTime_seconds-records.StartTime_seconds)
-#    if(t_total==0):  t_total=1 #division by zero prevention
-#    records.arrStatData[0][3]=records.arrStatData[0][0]*100/t_total
-#    records.arrStatData[1][3]=records.arrStatData[1][0]*100/t_total
-#    records.arrStatData[2][3]=records.arrStatData[2][0]*100/t_total
+    if(data.debug==True): print "Statistic data:", records.arrStatData
+
 
-    if(data.debug==True): print "Statistic data:",  records.arrStatData
 
 
 
 ###########################################################################
-## Initialise all variables in record container
+## Function:    InitRecord
+## Description: This function clears all data in the record and initialises
+##				it for the measurement
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def InitRecord():
     records.Index=0
@@ -590,7 +616,7 @@ def InitRecord():
     records.WakeUp_Song_Volume= -1
 
     for i in range(0, records.MaxArrayDataLen-1): #clear data of old records
-        for j in range(0,  6):
+        for j in range(0, 6):
             records.arrData[j][i]=0
 #        records.arrData[6][i]=0
 #        records.arrData[5][i]=""
@@ -599,50 +625,57 @@ def InitRecord():
 
 
 
+
+
+
 ###########################################################################
-## Print out all data of record container
+## Function:    PrintRecordData
+## Description: This function prints out all data in the record.
+##				It is only used for debugging
+## Parameters:  ShowArray: True/False
+## Returns:     none
 ###########################################################################
 def PrintRecordData(ShowArray=True):
     print "###################### RECORD DATA #######################"
-    print "Index:",  records.Index
-    print "LastIndex:",  records.LastIndex
-    print "StartTime_tuple:",  records.StartTime_tuple
-    print "StartTime_seconds:",  records.StartTime_seconds
-    print "EndTime_tuple:",  records.EndTime_tuple
-    print "EndTime_seconds:",  records.EndTime_seconds
-    print "AlarmIsSet:",  records.AlarmIsSet
-    print "AlarmTime_tuple:",  records.AlarmTime_tuple
-    print "AlarmTime_seconds:",  records.AlarmTime_seconds
-    print "AlarmTimeWindowStart_tuple:",  records.AlarmTimeWindowStart_tuple
-    print "AlarmTimeWindowStart_seconds:",  records.AlarmTimeWindowStart_seconds
-    print "AlarmTimeWindowEnd_tuple:",  records.AlarmTimeWindowEnd_tuple
-    print "AlarmTimeWindowEnd_seconds",  records.AlarmTimeWindowEnd_seconds
-    print "AlarmTimeWindow_minutes:",  records.AlarmTimeWindow_minutes
-    print "Note:",  records.Note
-    print "Sampling_interval:",  records.Sampling_interval
-    print "Sample_smoothing:",  records.Sample_smoothing
-    print "Value_smoothing:",  records.Value_smoothing
-    print "Trigger:",  records.Trigger
-    print "Status:",  records.statusID,  records.status
+    print "Index:", records.Index
+    print "LastIndex:", records.LastIndex
+    print "StartTime_tuple:", records.StartTime_tuple
+    print "StartTime_seconds:", records.StartTime_seconds
+    print "EndTime_tuple:", records.EndTime_tuple
+    print "EndTime_seconds:", records.EndTime_seconds
+    print "AlarmIsSet:", records.AlarmIsSet
+    print "AlarmTime_tuple:", records.AlarmTime_tuple
+    print "AlarmTime_seconds:", records.AlarmTime_seconds
+    print "AlarmTimeWindowStart_tuple:", records.AlarmTimeWindowStart_tuple
+    print "AlarmTimeWindowStart_seconds:", records.AlarmTimeWindowStart_seconds
+    print "AlarmTimeWindowEnd_tuple:", records.AlarmTimeWindowEnd_tuple
+    print "AlarmTimeWindowEnd_seconds", records.AlarmTimeWindowEnd_seconds
+    print "AlarmTimeWindow_minutes:", records.AlarmTimeWindow_minutes
+    print "Note:", records.Note
+    print "Sampling_interval:", records.Sampling_interval
+    print "Sample_smoothing:", records.Sample_smoothing
+    print "Value_smoothing:", records.Value_smoothing
+    print "Trigger:", records.Trigger
+    print "Status:", records.statusID, records.status
 
-    print "Use_Lucid_Dream_Song:",  records.Use_Lucid_Dream_Song
-    print "Lucid_Dream_Song_Start_tuple:",  records.Lucid_Dream_Song_Start_tuple
-    print "Lucid_Dream_Song:",  records.Lucid_Dream_Song
-    print "Lucid_Dream_Song_Delay:",  records.Lucid_Dream_Song_Delay
-    print "Lucid_Dream_Song_Duration:",  records.Lucid_Dream_Song_Duration
-    print "Lucid_Dream_Song_Volume:",  records.Lucid_Dream_Song_Volume
+    print "Use_Lucid_Dream_Song:", records.Use_Lucid_Dream_Song
+    print "Lucid_Dream_Song_Start_tuple:", records.Lucid_Dream_Song_Start_tuple
+    print "Lucid_Dream_Song:", records.Lucid_Dream_Song
+    print "Lucid_Dream_Song_Delay:", records.Lucid_Dream_Song_Delay
+    print "Lucid_Dream_Song_Duration:", records.Lucid_Dream_Song_Duration
+    print "Lucid_Dream_Song_Volume:", records.Lucid_Dream_Song_Volume
 
-    print "Use_WakeUp_Song:",  records.Use_WakeUp_Song
-    print "WakeUp_Song_Start_tuple:",  records.WakeUp_Song_Start_tuple
-    print "WakeUp_Song:",  records.WakeUp_Song
-    print "WakeUp_Song_Duration:",  records.WakeUp_Song_Duration
-    print "WakeUp_Song_Volume:",  records.WakeUp_Song_Volume
+    print "Use_WakeUp_Song:", records.Use_WakeUp_Song
+    print "WakeUp_Song_Start_tuple:", records.WakeUp_Song_Start_tuple
+    print "WakeUp_Song:", records.WakeUp_Song
+    print "WakeUp_Song_Duration:", records.WakeUp_Song_Duration
+    print "WakeUp_Song_Volume:", records.WakeUp_Song_Volume
 
     print "UseAlternativeAlarm:", records.UseAlternativeAlarm
     print "AlternativeAlarm:", records.AlternativeAlarm
 
     if(ShowArray==True):
         for i in range(0, records.Index): #print data of  records
-            print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
+            print records.arrData[0][i], records.arrData[1][i], records.arrData[2][i], records.arrData[3][i], records.arrData[4][i], records.arrData[5][i], records.arrData[6][i]
 
     print "##########################################################"
